@@ -1,4 +1,4 @@
-from ddop.metrics._newsvendor import pairwise_costs, average_costs, total_costs, prescriptiveness_score
+from ddop.metrics._costs import pairwise_costs, average_costs, total_costs, prescriptiveness_score
 from ddop.metrics._scorer import make_scorer
 
 __all__ = ["pairwise_costs", "total_costs", "average_costs", "prescriptiveness_score",
